package com.huimv.farm.damsubsidy.controller;


import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huimv.farm.damsubsidy.common.token.TokenSign;
import com.huimv.farm.damsubsidy.common.utils.BankUtil;
import com.huimv.farm.damsubsidy.common.utils.Result;
import com.huimv.farm.damsubsidy.common.utils.ResultCode;
import com.huimv.farm.damsubsidy.common.utils.UploadImage;
import com.huimv.farm.damsubsidy.entity.BaseUserBank;
import com.huimv.farm.damsubsidy.entity.SysUser;
import com.huimv.farm.damsubsidy.service.IBaseUserBankService;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * <p>
 *  前端控制器
 * </p>
 *
 * @author author
 * @since 2023-05-18
 */
@RestController
@CrossOrigin
@RequestMapping("/base-user-bank")
public class BaseUserBankController {
    @Resource
    private IBaseUserBankService baseUserBankService;
    @Resource
    private UploadImage uploadImage;

    @PostMapping("/listBankCard")
    public Result listBankCard(HttpServletRequest httpServletRequest, @RequestBody Map<String, String> paramsMap){
        String pageNum = paramsMap.get("pageNum");
        String pageSize = paramsMap.get("pageSize");
        QueryWrapper<BaseUserBank> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("user_id",TokenSign.getMemberIdByJwtToken(httpServletRequest));
        IPage<BaseUserBank> page = baseUserBankService.page(new Page<BaseUserBank>(Integer.parseInt(pageNum), Integer.parseInt(pageSize)), queryWrapper);
        return new Result(ResultCode.SUCCESS,page);
    }

    @PostMapping("/addBankCard")
    public Result addBankCard(HttpServletRequest httpServletRequest,
                              @RequestParam("bankCardImg") MultipartFile bankCardImg,
                              @RequestParam("bankCardId") String bankCardId,
                              @RequestParam("userName") String userName,
                              @RequestParam("phone") String phone,
                              @RequestParam("bankName") String bankName) throws IOException {
        if (!(BankUtil.checkBankCard(bankCardId))) {
            return new Result(10001, "卡号不符合标准,请检查银行卡号是否正确!", false);
        }
        if(baseUserBankService.count(new QueryWrapper<BaseUserBank>().eq("bank_id",bankCardId)) !=0){
            return new Result(10001,"该卡已绑定!",false);
        }
//        String content = UploadImage.getImageCom(bankCardImg);
        String content = uploadImage.getImageCom(bankCardImg);
        BaseUserBank baseUserBank = new BaseUserBank();
        baseUserBank.setBankId(bankCardId);
        baseUserBank.setUserId(TokenSign.getMemberIdByJwtToken(httpServletRequest));
        baseUserBank.setUserName(userName);
        baseUserBank.setPhone(phone);
        baseUserBank.setBankName(bankName);
        baseUserBank.setBankImgUrl(content);
        if (baseUserBankService.save(baseUserBank)) {
            return Result.SUCCESS();
        }else {
            return Result.ERROR();
        }
    }

    @PostMapping("/deleteBankCard")
    public Result deleteBankCard(@RequestBody Map<String, String> paramsMap){
        String id = paramsMap.get("id");
        if (!baseUserBankService.removeById(id)) {
            return Result.ERROR();
        }
        return Result.SUCCESS();
    }

    @PostMapping("/listPersonalCard")
    public Result listPersonalCard(HttpServletRequest httpServletRequest){
        List<BaseUserBank> baseUserBanks = baseUserBankService.list(new QueryWrapper<BaseUserBank>().eq("user_id", TokenSign.getMemberIdByJwtToken(httpServletRequest)));
        if (ObjectUtil.isEmpty(baseUserBanks)){
            List<BaseUserBank> userBank = new ArrayList<>();
            return new Result(ResultCode.SUCCESS,userBank);
        }else {
            return new Result(ResultCode.SUCCESS,baseUserBanks);
        }

    }

    @PostMapping("/getBankName")
    public Result getBankName(@RequestBody Map<String,String> map){
        String bankCardId = map.get("bankCardId");
        System.out.println(bankCardId);
        if (!(BankUtil.checkBankCard(bankCardId))) {
            return new Result(10001, "卡号不符合标准,请检查银行卡号是否正确!", false);
        }
        String bankName = BankUtil.getname(bankCardId);
        if (ObjectUtil.isEmpty(bankName)) {
            return new Result(10001, "寻找不到银行卡开户行!", false);
        }
        return new Result(ResultCode.SUCCESS,bankName);
    }

}
