package com.huimv.farm.damsubsidy.service.impl;

import cn.hutool.core.date.DateTime;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.huimv.farm.damsubsidy.common.token.TokenSign;
import com.huimv.farm.damsubsidy.common.utils.*;
import com.huimv.farm.damsubsidy.entity.*;
import com.huimv.farm.damsubsidy.entity.vo.BillBuyInfoVo;
import com.huimv.farm.damsubsidy.entity.BillLandingInspection;
import com.huimv.farm.damsubsidy.mapper.BaseAnimalMapper;
import com.huimv.farm.damsubsidy.mapper.BillBuyInfoMapper;
import com.huimv.farm.damsubsidy.mapper.BillLandingInspectionMapper;
import com.huimv.farm.damsubsidy.mapper.SysUserMapper;
import com.huimv.farm.damsubsidy.service.IBillBuyInfoService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.transaction.interceptor.TransactionAspectSupport;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 交易信息 服务实现类
 * </p>
 *
 * @author author
 * @since 2023-04-26
 */
@Service
public class BillBuyInfoServiceImpl extends ServiceImpl<BillBuyInfoMapper, BillBuyInfo> implements IBillBuyInfoService {
    @Resource
    private BaseAnimalMapper baseAnimalMapper;
    @Resource
    private BillBuyInfoMapper billBuyInfoMapper;
    @Resource
    private SysUserMapper sysUserMapper;
    @Resource
    private BillLandingInspectionMapper billLandingInspectionMapper;
    @Autowired
    private UploadImage uploadImage;
    @Override
    @Transactional(rollbackFor = RuntimeException.class)
    public synchronized Result addTransaction(HttpServletRequest httpServletRequest, MultipartFile buyImage1, MultipartFile buyImage2, MultipartFile buyImage3, MultipartFile buyImage4, MultipartFile buyImage5, MultipartFile image1, MultipartFile image2, String inspectionNum, String cargoOwner, String ownerPhone, String animalType, String animalNumberUp, String useTo, String startTran, String reachTran, String veter, String seller, String sellerId, String buyer, String buyerId, String eartags, String buyerPhone, String sellerPhone) throws IOException {
        Long userId = TokenSign.getMemberIdByJwtToken(httpServletRequest);
        BillBuyInfo billBuyInfo1 = billBuyInfoMapper.selectOne(new QueryWrapper<BillBuyInfo>().eq("create_user", userId).eq("bill_buy_status",1));
        int total = Integer.parseInt(animalNumberUp);
        SysUser sysUser = sysUserMapper.selectOne(new QueryWrapper<SysUser>().eq("id", userId));
        String veterId = sysUser.getVeterId();

        EartagResult eartagResult = EartagUtil.getEartagCollection(eartags);
        if (!eartagResult.getSuccess()){
            return new Result(10001,eartagResult.getMsg(),false);
        }
        if (eartagResult.getEartagList().size() != eartagResult.getEartagSet().size()) {
            return new Result(10001,"耳标号存在重复",false);
        }
        if (eartagResult.getEartagList().size() != total){
           return new Result(10001,"交易数量与实际耳标号数量不符!",false);
        }
        for (String eartagNo : eartagResult.getEartagList()) {
            BaseAnimal baseAnimal = baseAnimalMapper.selectOne(new QueryWrapper<BaseAnimal>().eq("earatg_no", eartagNo));
            baseAnimal.setBelongToUser(Long.valueOf(buyerId));
            baseAnimal.setBuyerId(Long.valueOf(buyerId));
            baseAnimal.setSellerId(Long.valueOf(sellerId));
            baseAnimal.setBuyerName(buyer);
            baseAnimal.setSellerName(seller);
            baseAnimal.setAnimalStatus(2);
            baseAnimal.setBuyTime(DateTime.now());
            baseAnimalMapper.updateById(baseAnimal);
        }
        String content3 = "";
        String content = uploadImage.getImageCom(image1);
        String content2 = uploadImage.getImageCom(image2);
        content3 = getUrl(content3,buyImage1);
        content3 = getUrl(content3,buyImage2);
        content3 = getUrl(content3,buyImage3);
        content3 = getUrl(content3,buyImage4);
        content3 = getUrl(content3,buyImage5);

        BillLandingInspection billLandingInspection = new BillLandingInspection();
        billLandingInspection.setInspectionNum(inspectionNum);
        billLandingInspection.setInspectionName(buyer+"的产地检疫");
        billLandingInspection.setCargoOwner(cargoOwner);
        billLandingInspection.setOwnerPhone(ownerPhone);
        billLandingInspection.setAnimalType(Integer.parseInt(animalType));
        billLandingInspection.setAnimalNumberUp(animalNumberUp);
        billLandingInspection.setUseTo(useTo);
        billLandingInspection.setStartTran(startTran);
        billLandingInspection.setReachTran(reachTran);
        billLandingInspection.setVeterId(Integer.parseInt(veterId));
        billLandingInspection.setEartags(eartags);
        billLandingInspection.setInspectionSch(4);
        billLandingInspection.setInspectionType(1);
        billLandingInspection.setReviewed(sysUser.getUserName());
        billLandingInspection.setReviewedTime(DateTime.now());
        billLandingInspection.setCreateUser(userId);
        billLandingInspection.setCreateTime(DateTime.now());



        if (ObjectUtil.isEmpty(billBuyInfo1)){
            BillBuyInfo billBuyInfo = new BillBuyInfo();
            billBuyInfo.setBuyName(seller+"和"+buyer+"的交易信息");
            billBuyInfo.setInspectionNum(inspectionNum);
            billBuyInfo.setBuyerName(buyer);
            billBuyInfo.setSellerName(seller);
            billBuyInfo.setSellerPhone(sellerPhone);
            billBuyInfo.setBuyerPhone(buyerPhone);
            billBuyInfo.setCreateUser(userId);
            billBuyInfo.setCreateTime(DateTime.now());
            billBuyInfo.setRealNumUp(animalNumberUp);
            billBuyInfo.setBuyPicUrl(content);
            billBuyInfo1.setBuyerId(Long.valueOf(buyerId));
            billBuyInfo.setSellerId(Long.valueOf(sellerId));
            billBuyInfo.setPayPicUrl(content2);
            billBuyInfo.setBuyPayGoodsPicUrl(content3);
            billBuyInfo.setRealEartag(eartags);
            billBuyInfo.setBillBuyStatus(2);
            this.save(billBuyInfo);
        }else {
            billBuyInfo1.setBuyName(seller+"和"+buyer+"的交易信息");
            billBuyInfo1.setInspectionNum(inspectionNum);
            billBuyInfo1.setBuyerName(buyer);
            billBuyInfo1.setSellerName(seller);
            billBuyInfo1.setSellerPhone(sellerPhone);
            billBuyInfo1.setBuyerPhone(buyerPhone);
            billBuyInfo1.setCreateUser(userId);
            billBuyInfo1.setBuyerId(Long.valueOf(buyerId));
            billBuyInfo1.setSellerId(Long.valueOf(sellerId));
            billBuyInfo1.setCreateTime(DateTime.now());
            billBuyInfo1.setRealNumUp(animalNumberUp);
            billBuyInfo1.setBuyPicUrl(content);
            billBuyInfo1.setPayPicUrl(content2);
            billBuyInfo1.setBuyPayGoodsPicUrl(content3);
            billBuyInfo1.setRealEartag(eartags);
            billBuyInfo1.setBillBuyStatus(2);
            this.updateById(billBuyInfo1);
        }

        return Result.SUCCESS();
    }

    public  String getUrl(String content, MultipartFile image) throws IOException {
        if (ObjectUtil.isNotEmpty(image)){
            if ( !"".equals(content)){
                content = content +","+uploadImage.getImageCom(image);
            }else {
                content =   content +uploadImage.getImageCom(image);
            }
        }
        return content;
    }

    @Override
    @Transactional
    public Result saveTransaction(HttpServletRequest httpServletRequest,Map<String, String> paramsMap) {
        String inspectionNum = paramsMap.get("inspectionNum");
        String seller = paramsMap.get("seller");
        String buyer = paramsMap.get("buyer");
        String num = paramsMap.get("num");
        String eartags = paramsMap.get("eartags");
        String buyerPhone = paramsMap.get("buyerPhone");
//        String imgname = "成功";
//        String originalFilename = image1.getOriginalFilename();
//        String filenameExtension = StringUtils.getFilenameExtension(originalFilename);
//        String path = DateUtil.format(new Date(),"yyyy-MM");
//        try {
//            InputStream inputStream = image1.getInputStream();
//            BufferedInputStream in = new BufferedInputStream(inputStream);
//            ByteArrayOutputStream out = new ByteArrayOutputStream(1024);
//
//            byte[] temp = new byte[1024];
//            int size = 0;
//            while ((size = in.read(temp)) != -1) {
//                out.write(temp, 0, size);
//            }
//            in.close();
//            byte[] content = out.toByteArray();
//            imgname = UUID.randomUUID()+"."+filenameExtension;
//            UploadImage.sshSftp(content,path, imgname);
//        } catch (Exception e) {
//            e.printStackTrace();
//        }
//        String content = "https://dam.img.ifarmcloud.com:8030/images/"+path +"/"+imgname;
//
//        String imgname2 = "成功";
//        String originalFilename2 = image2.getOriginalFilename();
//        String filenameExtension2 = StringUtils.getFilenameExtension(originalFilename2);
//        String path2 = DateUtil.format(new Date(),"yyyy-MM");
//        try {
//            InputStream inputStream = image2.getInputStream();
//            BufferedInputStream in = new BufferedInputStream(inputStream);
//            ByteArrayOutputStream out = new ByteArrayOutputStream(1024);
//
//            byte[] temp = new byte[1024];
//            int size = 0;
//            while ((size = in.read(temp)) != -1) {
//                out.write(temp, 0, size);
//            }
//            in.close();
//            byte[] content2 = out.toByteArray();
//            imgname2 = UUID.randomUUID()+"."+filenameExtension2;
//            UploadImage.sshSftp(content2,path2, imgname2);
//        } catch (Exception e) {
//            e.printStackTrace();
//        }
//        String content2 = "https://dam.img.ifarmcloud.com:8030/images/"+path2 +"/"+imgname2;
//
//        String imgname3 = "成功";
//        String originalFilename3 = image3.getOriginalFilename();
//        String filenameExtension3 = StringUtils.getFilenameExtension(originalFilename3);
//        String path3 = DateUtil.format(new Date(),"yyyy-MM");
//        try {
//            InputStream inputStream = image3.getInputStream();
//            BufferedInputStream in = new BufferedInputStream(inputStream);
//            ByteArrayOutputStream out = new ByteArrayOutputStream(1024);
//
//            byte[] temp = new byte[1024];
//            int size = 0;
//            while ((size = in.read(temp)) != -1) {
//                out.write(temp, 0, size);
//            }
//            in.close();
//            byte[] content3 = out.toByteArray();
//            imgname3 = UUID.randomUUID()+"."+filenameExtension3;
//            UploadImage.sshSftp(content3,path3, imgname3);
//        } catch (Exception e) {
//            e.printStackTrace();
//        }
//        String content3 = "https://dam.img.ifarmcloud.com:8030/images/"+path3 +"/"+imgname3;

        BillBuyInfo billBuyInfo1 = billBuyInfoMapper.selectOne(new QueryWrapper<BillBuyInfo>().eq("create_user", TokenSign.getUserName(httpServletRequest)).eq("bill_buy_status",1));
        if (ObjectUtil.isEmpty(billBuyInfo1)){
            BillBuyInfo billBuyInfo = new BillBuyInfo();
            billBuyInfo.setBuyName(seller+"和"+buyer+"的交易信息");
            billBuyInfo.setInspectionNum(inspectionNum);
            billBuyInfo.setBuyerName(buyer);
            billBuyInfo1.setBuyerPhone(buyerPhone);
            billBuyInfo.setSellerName(seller);
            billBuyInfo.setCreateUser(TokenSign.getMemberIdByJwtToken(httpServletRequest));
            billBuyInfo.setCreateTime(DateTime.now());
            billBuyInfo.setRealNumUp(num);
//            billBuyInfo.setBuyPicUrl(content);
//            billBuyInfo.setPayPicUrl(content2);
//            billBuyInfo.setBuyPayGoodsPicUrl(content3);
            billBuyInfo.setRealEartag(eartags);
            billBuyInfo.setBillBuyStatus(1);
            this.save(billBuyInfo);
        }else {
            billBuyInfo1.setBuyName(seller+"和"+buyer+"的交易信息");
            billBuyInfo1.setInspectionNum(inspectionNum);
            billBuyInfo1.setBuyerName(buyer);
            billBuyInfo1.setBuyerPhone(buyerPhone);
            billBuyInfo1.setSellerName(seller);
            billBuyInfo1.setCreateUser(TokenSign.getMemberIdByJwtToken(httpServletRequest));
            billBuyInfo1.setCreateTime(DateTime.now());
            billBuyInfo1.setRealNumUp(num);
//            billBuyInfo1.setBuyPicUrl(content);
//            billBuyInfo1.setPayPicUrl(content2);
//            billBuyInfo1.setBuyPayGoodsPicUrl(content3);
            billBuyInfo1.setRealEartag(eartags);
            billBuyInfo1.setBillBuyStatus(1);
            this.updateById(billBuyInfo1);
        }
        return Result.SUCCESS();
    }

    @Override
    public Result getLast(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        BillBuyInfoVo billBuyInfo = billBuyInfoMapper.getLast(TokenSign.getMemberIdByJwtToken(httpServletRequest));
        if (ObjectUtil.isEmpty(billBuyInfo)){
            return new Result(ResultCode.SUCCESS,null);
        }else {
            return new Result(ResultCode.SUCCESS,billBuyInfo);
        }
    }

    @Override
    public Result listDetail(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String id = paramsMap.get("id");
        BillBuyInfoVo billBuyInfo= billBuyInfoMapper.listDetail(id);
        return new Result(ResultCode.SUCCESS,billBuyInfo);
    }
}
