package com.huimv.farm.damsubsidy.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huimv.farm.damsubsidy.common.token.TokenSign;
import com.huimv.farm.damsubsidy.common.utils.PageUtils;
import com.huimv.farm.damsubsidy.common.utils.Result;
import com.huimv.farm.damsubsidy.common.utils.ResultCode;
import com.huimv.farm.damsubsidy.entity.*;
import com.huimv.farm.damsubsidy.mapper.*;
import com.huimv.farm.damsubsidy.service.ISysUserService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.RequestBody;

import javax.servlet.http.HttpServletRequest;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author author
 * @since 2023-04-26
 */
@Service
public class SysUserServiceImpl extends ServiceImpl<SysUserMapper, SysUser> implements ISysUserService {

    @Autowired
    private SysUserMapper userMapper;
    @Autowired
    private PovertyUserRegistMapper povertyUserRegistMapper;
    @Autowired
    private BaseVeterStationMapper baseVeterStationMapper;
    @Autowired
    private RedisTemplate<String, String> redisTemplate;
    @Autowired
    private AreaAllMapper areaAllMapper;

    @Autowired
    private AccountGroupMapper accountGroupMapper;

    @Override
    public Result loginMultilevel(HttpServletRequest httpServletRequest, Map<String, String> paramsMap, String remoteHost) {
        //TODO 验证码接口暂时不写，验证码验证接口写在此接口之前，这里默认验证码已经正确！
        String phone = paramsMap.get("phone");
        String code = paramsMap.get("code");
        //是否存在
        Boolean aBoolean = redisTemplate.hasKey("xumu:" + phone);
        if (!aBoolean) {
            return new Result(10001, "该手机号未发送验证码或验证码过期！！！", false);
        }
        System.out.println(aBoolean);
        String s = redisTemplate.opsForValue().get("xumu:" + phone);
        if (!code.equals(s)) {
            return new Result(10001, "验证码错误！！", false);
        } else {
            System.out.println("登录成功");

            QueryWrapper<SysUser> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("phone", phone);
            SysUser sysUser = userMapper.selectOne(queryWrapper);
            if (ObjectUtil.isEmpty(sysUser)) {
                return new Result(10004, "用户暂未注册，请注册！", false);
            } else {
                if (sysUser.getAccoutType() == 1) {
                    this.updateById(sysUser.setLastIp(remoteHost));
                    return new Result(ResultCode.SUCCESS, sysUser);
                } if (sysUser.getAccoutType() == 0){
                    return new Result(10002, "该账号未审核！", false);
                }if (sysUser.getAccoutType() == 2){
                    return new Result(10002, "该账号已停用！", false);
                }
                if (sysUser.getAccoutType() == 3){
                    return new Result(10002, "该账号已注销！", false);
                } else {
                    return new Result(10002, "该账号审核未通过！", false);
                }
            }
        }
    }

    @Override
    public Result loginOne() {
        String phone = "13112341236";
        QueryWrapper<SysUser> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("phone", phone);
        return new Result(ResultCode.SUCCESS, userMapper.selectOne(queryWrapper));
    }

    @Override
    public Result loginMultilevelClient(String accountName, String password, String remoteHost) {

        QueryWrapper<SysUser> wrapper = new QueryWrapper<>();
        wrapper.eq("account_num", accountName).eq("password", password);
        SysUser accountMultilevel = userMapper.selectOne(wrapper);

        if (ObjectUtil.isEmpty(accountMultilevel)) {
            return new Result(10001, "账号不存在或密码错误", false);
        }

        Integer accoutType = accountMultilevel.getAccoutType();

        if (accoutType != 1) {
            return new Result(10001, "账号未启用", false);
        }

        this.updateById(accountMultilevel.setLastIp(remoteHost));
        return new Result(ResultCode.SUCCESS, accountMultilevel);
    }

    @Override
    public Result addXiang(SysUser sysUser, Long userId) {
        SysUser byId = this.getById(userId);

        String accountNum = sysUser.getAccountNum();
        String password = sysUser.getPassword();
        String phone = sysUser.getPhone();

        if (StringUtils.isBlank(accountNum) || StringUtils.isBlank(password)) {
            return new Result(10001, "输入有误，账号密码为空", false);
        }

        if (StringUtils.isBlank(phone) || !phone.matches("1[3-9]\\d{9}")) {
            return new Result(10001, "手机号格式不正确", false);
        }

        int countNum = this.count(new QueryWrapper<SysUser>().eq("account_num", accountNum));
        if (countNum > 0) {
            return new Result(10001, "账号已存在", false);
        }
        Integer phone1 = this.count(new QueryWrapper<SysUser>().eq("phone", phone));
        if (phone1 > 0) {
            return new Result(10001, "手机号已存在", false);
        }

        Date date = new Date();
        sysUser.setCreateTime(date);
        sysUser.setUpdateTime(date);
        sysUser.setCreateUser(userId);
        sysUser.setUpdateUser(userId + "");
        sysUser.setUserType(4);
        sysUser.setIsRealName(0);
        sysUser.setAccoutType(1);
        sysUser.setPid(userId);
        sysUser.setPids(byId.getPids() + "," + userId);
        this.save(sysUser);
        AccountGroup accountGroup = new AccountGroup();
        accountGroup.setAccountId(sysUser.getId());
        accountGroup.setGroupId(36);
        accountGroupMapper.insert(accountGroup);

        return new Result(10000, "添加成功", true);
    }

    @Override
    public Result remove(String ids, Long userId) {
        Date date = new Date();
        for (String s : ids.split(",")) {
            this.removeById(s);
        }
        return new Result(ResultCode.SUCCESS, "删除成功");
    }

    @Override
    public Result updateUser(SysUser sysUser, Long userId) {
        Date date = new Date();
        sysUser.setUpdateUser(userId + "");
        sysUser.setUpdateTime(date);
        updateById(sysUser);
        return new Result(ResultCode.SUCCESS, "修改成功");
    }

    @Override
    public Result addImg(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String img = paramsMap.get("permitImg");
        String id = paramsMap.get("id");
        SysUser user = userMapper.selectById(id);
        user.setPermit(img);
        userMapper.updateById(user);
        return new Result(ResultCode.SUCCESS, userMapper.selectById(id));
    }

    @Override
    public Result removeByIds(Map<String, String> paramsMap) {
        String ids = paramsMap.get("ids");
        String[] split = ids.split(",");
        for (String s : split) {
            userMapper.deleteById(s);
        }
        return new Result(10000, "删除成功", true);
    }

    @Override
    public Result login2(Map<String, String> paramsMap) {
        String phone = paramsMap.get("phone");
        if (!phone.matches("1[3-9]\\d{9}")) {
            return new Result(10001, "手机号格式不正确", false);
        }
        QueryWrapper<SysUser> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("phone", phone).eq("account_type", 1);
        SysUser user = userMapper.selectOne(queryWrapper);
        if (ObjectUtil.isEmpty(user)) {
            return new Result(10001, "用户不存在或账号不可用", false);
        }
        return new Result(ResultCode.SUCCESS, user);
    }


    @Transactional
    @Override
    public Result add(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {

        SysUser user = new SysUser();
        if (Integer.parseInt(paramsMap.get("type")) == 2) {
            user.setUserType(Integer.parseInt(paramsMap.get("type")));
            user.setUserName(paramsMap.get("userName"));
            user.setPhone(TokenSign.getPhone(httpServletRequest));
            user.setAddress(paramsMap.get("address"));
            user.setDetailedAdress(paramsMap.get("detailedAddress"));
            user.setDetailedAdressCode(paramsMap.get("detailedAdressCode"));
            user.setCreateTime(new Date());
            user.setPermit(paramsMap.get("idCordFrontUrl"));
            String s = paramsMap.get("detailedAdressCode");
            String[] split = s.split(",");
            user.setBriefAddressCode(split[split.length - 1]);
            user.setAccoutType(1);
            user.setIsRealName(1);
            user.setCompanyName(paramsMap.get("companyName"));
            user.setCompanyCode(paramsMap.get("companyCode"));
            user.setCompanyIdCardFront(paramsMap.get("companyIdCardFront"));
            user.setCompanyIdCardBack(paramsMap.get("companyIdCardBack"));
            QueryWrapper<SysUser> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("phone",TokenSign.getPhone(httpServletRequest));
            Integer integer = userMapper.selectCount(queryWrapper);
            QueryWrapper<SysUser> queryWrapper1 = new QueryWrapper<>();
            queryWrapper1.eq("user_name", paramsMap.get("userName"));
            Integer integer1 = userMapper.selectCount(queryWrapper1);
            if (integer1 == 0) {
                if (integer == 0) {
                    userMapper.insert(user);
                    return new Result(ResultCode.SUCCESS, user);
                } else {
                    return new Result(10001, "该手机号已被其他用户使用！", false);
                }
            }else{
                return new Result(10001, "该企业已存在，请重新注册！", false);
            }
        }
        user.setUserType(Integer.parseInt(paramsMap.get("type")));
        user.setUserName(paramsMap.get("userName"));
        user.setIdCard(paramsMap.get("idCord"));
        user.setPhone(paramsMap.get("phone"));
        user.setAddress(paramsMap.get("address"));
        user.setDetailedAdressCode(paramsMap.get("detailedAdressCode"));
        user.setDetailedAdress(paramsMap.get("detailedAddress"));

        user.setCreateTime(new Date());
        String s = paramsMap.get("detailedAdressCode");
        String[] split = s.split(",");
        String s1 = split[split.length - 1];
        user.setBriefAddressCode(s1);
        AreaAll id = areaAllMapper.selectOne(new QueryWrapper<AreaAll>().eq("id", s1));

        user.setBriefAddress(id.getName());


        if (Integer.parseInt(paramsMap.get("type")) == 1) {
            System.out.println(paramsMap.get("veterId"));
            user.setVeterId((paramsMap.get("veterId")));
        }
        user.setIdCardFrontUrl(paramsMap.get("idCordFrontUrl"));
        user.setIdCardBackUrl(paramsMap.get("idCordBackUrl"));


        if (Integer.parseInt(paramsMap.get("type")) == 3) {
            QueryWrapper<PovertyUserRegist> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("XM", paramsMap.get("userName")).eq("ZJHM", paramsMap.get("idCord"));
            //TODO 会有问题，不可能只有一个
            PovertyUserRegist povertyUserRegist = povertyUserRegistMapper.selectOne(queryWrapper);
            if (ObjectUtil.isEmpty(povertyUserRegist)) {
                user.setFarmType(2);
            } else if (povertyUserRegist.getIsDelete() == 1) {
                user.setFarmType(1);
            } else {
                user.setFarmType(0);
            }
            user.setFarmName(paramsMap.get("farmName"));
            user.setAccoutType(1);

            QueryWrapper<SysUser> queryWrapper1 = new QueryWrapper<>();
            queryWrapper1.eq("id_card", paramsMap.get("idCord"));
            SysUser user2 = userMapper.selectOne(queryWrapper1);
            if (ObjectUtil.isNotEmpty(user2)) {
                return new Result(10001, "", false);
            }
            QueryWrapper<SysUser> queryWrapper2 = new QueryWrapper<>();
            queryWrapper2.eq("phone", paramsMap.get("phone"));
            SysUser sysUser = userMapper.selectOne(queryWrapper2);
            if (ObjectUtil.isNotEmpty(sysUser) ) {
                if (sysUser.getIsRealName() == 1){
                    return new Result(10001, "用户已存在", false);
                }else {
                    sysUser.setUserType(Integer.parseInt(paramsMap.get("type")));
                    sysUser.setUserName(paramsMap.get("userName"));
                    sysUser.setIdCard(paramsMap.get("idCord"));
                    sysUser.setPhone(paramsMap.get("phone"));
                    sysUser.setAddress(paramsMap.get("address"));
                    sysUser.setDetailedAdressCode(paramsMap.get("detailedAdressCode"));
                    sysUser.setDetailedAdress(paramsMap.get("detailedAddress"));
                    sysUser.setBriefAddressCode(s1);
                    sysUser.setBriefAddress(id.getName());

                    sysUser.setIdCardFrontUrl(paramsMap.get("idCordFrontUrl"));
                    sysUser.setIdCardBackUrl(paramsMap.get("idCordBackUrl"));

                    sysUser.setCreateTime(new Date());
                    sysUser.setIsRealName(1);

                    if (ObjectUtil.isEmpty(povertyUserRegist)) {
                        sysUser.setFarmType(2);
                    } else if (povertyUserRegist.getIsDelete() == 1) {
                        sysUser.setFarmType(1);
                    } else {
                        sysUser.setFarmType(0);
                    }
                    sysUser.setFarmName(paramsMap.get("farmName"));
                    sysUser.setAccoutType(1);
                    userMapper.updateById(sysUser);
                    return new Result(ResultCode.SUCCESS,sysUser);
                }

            }else {
                if (!paramsMap.get("phone").equals(TokenSign.getPhone(httpServletRequest))) {
                    return new Result(10001, "实名手机号与当前手机号不一致", false);
                }
                user.setIsRealName(1);
                userMapper.insert(user);
                return new Result(ResultCode.SUCCESS, userMapper.selectOne(new QueryWrapper<SysUser>().eq("phone", paramsMap.get("phone"))));
            }
        } else {
            user.setAccoutType(0);
            user.setIsRealName(1);
            QueryWrapper<SysUser> queryWrapper1 = new QueryWrapper<>();
            queryWrapper1.eq("id_card", paramsMap.get("idCord"));
            SysUser user2 = userMapper.selectOne(queryWrapper1);
            if (ObjectUtil.isNotEmpty(user2)) {
                return new Result(10001, "用户已存在", false);
            }
            QueryWrapper<SysUser> queryWrapper2 = new QueryWrapper<>();
            queryWrapper2.eq("phone", paramsMap.get("phone"));
            SysUser sysUser = userMapper.selectOne(queryWrapper2);
            if (ObjectUtil.isNotEmpty(sysUser)) {
                return new Result(10001, "用户已存在", false);
            }
            if (!paramsMap.get("phone").equals(TokenSign.getPhone(httpServletRequest))) {
                return new Result(10001, "实名手机号与当前手机号不一致", false);
            }
            userMapper.insert(user);
            return new Result(10004, "待审核", false);
        }
    }

    @Override
    public Result edit(HttpServletRequest httpServletRequest, SysUser user) {
        userMapper.updateById(user);
        return new Result(10000, "修改成功！", true);
    }

    @Override
    public Result list(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        QueryWrapper<SysUser> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("phone", paramsMap.get("phone"));
        return new Result(ResultCode.SUCCESS, userMapper.selectOne(queryWrapper));
    }

    @Override
    public Result findPhone(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String userName = paramsMap.get("userName");
        String idCord = paramsMap.get("idCord");
        String phone = paramsMap.get("phone");
        if (!phone.matches("1[3-9]\\d{9}")) {
            return new Result(10001, "手机号格式不正确", false);
        }
        QueryWrapper<SysUser> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("user_name", userName).eq("id_card", idCord);
        SysUser user = userMapper.selectOne(queryWrapper);
        return new Result(ResultCode.SUCCESS, user.getPhone());
    }

    @Override
    public Result listPc(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String date = paramsMap.get("date");
        String word = paramsMap.get("word");
        String role = paramsMap.get("role");
        String pageSize = paramsMap.get("pageSize");
        String pageNum = paramsMap.get("pageNum");
        String type = paramsMap.get("type");

        if (pageSize == null || "".equals(pageSize)) {
            pageSize = "10";
        }
        if (pageNum == null || "".equals(pageNum)) {
            pageNum = "1";
        }

        QueryWrapper<SysUser> queryWrapper = new QueryWrapper<>();
        if (type == null || type == "") {
            if (role == null || role.equals("")) {
                queryWrapper.in("user_type",  1, 4);
            } else {
                queryWrapper.eq("user_type", role);
            }
            queryWrapper.between(StringUtils.isNotBlank(date), "create_time", date + " 00:00:00", date + " 23:59:59");
            queryWrapper.like(StringUtils.isNotBlank(word), "user_name", word)
                    .or().like(StringUtils.isNotBlank(word), "phone", word)
                    .or().like(StringUtils.isNotBlank(word), "id_card", word);
            queryWrapper.orderByDesc("create_time");
        } else if (Integer.parseInt(type) == 1) { //待审核
            if (role == null || role.equals("")) {
                queryWrapper.in("user_type",  1, 4);
            } else {
                queryWrapper.eq("user_type", role);
            }
            queryWrapper.eq("accout_type", 0)
                    .between(StringUtils.isNotBlank(date), "create_time", date + " 00:00:00", date + " 23:59:59")
                    .eq(StringUtils.isNotBlank(role), "user_type", role).
                    like(StringUtils.isNotBlank(word), "user_name", word)
                    .or().like(StringUtils.isNotBlank(word), "phone", word)
                    .or().like(StringUtils.isNotBlank(word), "id_card", word);
        } else {
            if (role == null || role.equals("")) {
                queryWrapper.in("user_type",  1, 4);
            } else {
                queryWrapper.eq("user_type", role);
            }
            queryWrapper.ge("accout_type", 1)
                    .between(StringUtils.isNotBlank(date), "create_time", date + " 00:00:00", date + " 23:59:59")
                    .eq(StringUtils.isNotBlank(role), "user_type", role)
                    .like(StringUtils.isNotBlank(word), "user_name", word)
                    .or().like(StringUtils.isNotBlank(word), "phone", word)
                    .or().like(StringUtils.isNotBlank(word), "id_card", word);
        }
        Page<SysUser> page = new Page<>(Integer.parseInt(pageNum), Integer.parseInt(pageSize));
        return new Result(ResultCode.SUCCESS, userMapper.selectPage(page, queryWrapper));
    }

    @Override
    public Result editState(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String id = paramsMap.get("id");
        Integer accoutType = Integer.parseInt(paramsMap.get("accoutType"));
        System.out.println(accoutType);
        SysUser user = userMapper.selectById(id);
        user.setAccoutType(accoutType);
        userMapper.updateById(user);
        AccountGroup accountGroup = new AccountGroup();
        accountGroup.setAccountId(user.getId());
        accountGroup.setGroupId(36);
        accountGroupMapper.insert(accountGroup);

        return new Result(10000, "修改成功", true);
    }

    @Override
    public Result listPc2(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String date = paramsMap.get("startTime");
        String word = paramsMap.get("word");
        String role = paramsMap.get("role");
        String pageSize = paramsMap.get("pageSize");
        String pageNum = paramsMap.get("pageNum");

        if (pageSize == null || pageSize == "") {
            pageSize = "10";
        }
        if (pageNum == null || pageNum == "") {
            pageNum = "1";
        }
        if (date != "") {
            date = date + " 00:00:00";
        }
        QueryWrapper<SysUser> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("accout_type", 1).or().eq("accout_type", 4).ge("create_time", date)
                .eq("user_type", role).like("user_name", word).or().like("phone", word)
                .or().like("id_card", word);
        Page<SysUser> page = new Page<>(Integer.parseInt(pageNum), Integer.parseInt(pageSize));
        Page<SysUser> sysUserPage = userMapper.selectPage(page, queryWrapper);
        return new Result(ResultCode.SUCCESS, sysUserPage);
    }


    //
    @Override
    public Result findUserAccount(String searchStr, int pageNum, int pageSize, Long userId) {

        QueryWrapper<SysUser> wrapper = new QueryWrapper<>();
        wrapper.like("pids", userId).or().eq("id", userId);
        IPage<SysUser> page = this.page(new Page<>(pageNum, pageSize), wrapper);
        return new Result(ResultCode.SUCCESS, page);
    }

    @Override
    public Result add(SysUser sysUser, Long userId) {

        int account = this.count(new QueryWrapper<SysUser>().eq("account_num", sysUser.getAccountNum()));
        if (account > 0) {
            return new Result(10001, "该账号已经存在，请重新创建", false);

        }
        SysUser byId = this.getById(userId);

        sysUser.setPid(userId);
        sysUser.setPids(byId.getPids() + "," + userId);
        userMapper.insert(sysUser);
        return new Result(10000, "添加成功", true);
    }

    @Override
    public Result setAccountStatus(List<Integer> ids, Integer status) {
        try {
            for (Integer id : ids) {
                SysUser account = new SysUser();
                account.setId(Long.valueOf(id));
                account.setAccoutType(status);
                this.updateById(account);
            }
        } catch (Exception e) {
            return new Result(10001, "插入失败", false);
        }
        String message = "";
        if (status == 1) {
            message = "你选择的账号已经启用。";
        } else {
            message = "你选择的账号已经暂停启用。";
        }
        return new Result(10000, message, true);
    }

    @Override
    public List<Long> getAllChildId(Long userId) {
        List<SysUser> pids = this.list(new QueryWrapper<SysUser>().like("pids", userId + ""));
        List<Long> list = new ArrayList<>();
        for (SysUser pid : pids) {
            list.add(pid.getId());
        }
        list.add(userId);
        return list;
    }

    @Override
    public Result listSubordinate(String searchStr, Integer pageNum, Integer pageSize, Long userId) {

        QueryWrapper<SysUser> wrapper = new QueryWrapper<>();
        wrapper.like("pids", userId);
        wrapper.ne("id", userId);
        wrapper.eq("is_delete", 0);
        if (StringUtils.isNotBlank(searchStr)) {
            wrapper.and(i -> i.like("user_name", searchStr).or().like("account_num", searchStr));
        }

        IPage<SysUser> page = this.page(new Page<SysUser>(Long.valueOf(pageNum), Long.valueOf(pageSize)), wrapper);
        return new Result(ResultCode.SUCCESS, page);
    }

    @Override
    public Result getLastFarmId(Integer userId) {
        SysUser sysUser = userMapper.selectById(userId);
        Integer lastFarmId = sysUser.getLastVeter();
        String farmIds = sysUser.getVeterIds();
        if (farmIds == null) {
            return new Result(10001, "该账号没有绑定兽医站", true);
        }
        if (lastFarmId == null) {
            String[] split = farmIds.split(",");
            String s = split[0];
            sysUser.setLastVeter(Integer.valueOf(s));
            userMapper.updateById(sysUser);
            return new Result(ResultCode.SUCCESS, s);
        }
        return new Result(ResultCode.SUCCESS, lastFarmId);
    }


    @Override
    public Result listFarmer(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String pageNum = paramsMap.get("pageNum");
        String pageSize = paramsMap.get("pageSize");
        String code = paramsMap.get("code");
        String farmType = paramsMap.get("farmType");
        SysUser sysUser = this.getById(TokenSign.getMemberIdByJwtToken(httpServletRequest));
        Integer userType = sysUser.getUserType();

        QueryWrapper<SysUser> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(!StringUtils.isBlank(farmType), "farm_type", farmType);
        if (userType == 0) {
            queryWrapper.eq("user_type", 3)
                    .like(StringUtils.isNotBlank(code), "detailed_adress_code", code);
        } else {
            queryWrapper.eq("user_type", 3)
                    .like(StringUtils.isNotBlank(code),"detailed_adress_code", sysUser.getBriefAddressCode());
        }
        Page<SysUser> page = new Page(Integer.parseInt(pageNum), Integer.parseInt(pageSize));
        IPage<SysUser> sysUsers = this.page(page, queryWrapper);
        return new Result(ResultCode.SUCCESS, sysUsers);
    }

    @Override
    public Result listCompany(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String pageNum = paramsMap.get("pageNum");
        String pageSize = paramsMap.get("pageSize");
        String code = paramsMap.get("code");//区域编码
        String name = paramsMap.get("name");//企业名称
        if (pageNum == null || pageNum.equals("")) {
            pageNum = "1";
        }
        if (pageSize == null || pageSize.equals("")) {
            pageSize = "20";
        }
        QueryWrapper<SysUser> queryWrapper = new QueryWrapper<>();
        queryWrapper.like(StringUtils.isNotBlank(code), "brief_address_code", code).eq("user_type", 2)
                .like(StringUtils.isNotBlank(name),"user_name", name).ge("id",5);
        Page<SysUser> page = new Page<>(Integer.parseInt(pageNum), Integer.parseInt(pageSize));
        return new Result(ResultCode.SUCCESS,userMapper.selectPage(page,queryWrapper));
    }

    @Override
    public Result listSeller() {
        List<SysUser> seller = this.list(new QueryWrapper<SysUser>().in("user_type", 2, 3).eq("is_real_name", 1));
        return new Result(ResultCode.SUCCESS,seller);
    }

    @Override
    public Result listBuyer() {
        List<SysUser> buyer = this.list(new QueryWrapper<SysUser>().in("user_type", 3).eq("is_real_name", 1));
        return new Result(ResultCode.SUCCESS,buyer);
    }

}
